@@ -47,14 +47,14 @@ class PriceList(ModelSQL, ModelView):
     _description = __doc__
     name = fields.Char('Name', required=True, translate=True)
     company = fields.Many2One('company.company', 'Company', required=True,
-        select=1, domain=[
+        select=True, domain=[
             ('id', If(Eval('context', {}).contains('company'), '=', '!='),
                 Eval('context', {}).get('company', 0)),
             ])
     lines = fields.One2Many('product.price_list.line', 'price_list', 'Lines')
 
     def default_company(self):
-        return Transaction().context.get('company') or False
+        return Transaction().context.get('company')
 
     def _get_context_price_list_line(self, party, product, unit_price,
             quantity, uom):
@@ -116,7 +116,7 @@ class PriceList(ModelSQL, ModelView):
             pattern = {}
 
         pattern = pattern.copy()
-        pattern['product'] = product and product.id or False
+        pattern['product'] = product and product.id or None
         pattern['quantity'] = uom_obj.compute_qty(uom, quantity,
                 product.default_uom, round=False)
 
@@ -138,7 +138,7 @@ class PriceListLine(ModelSQL, ModelView):
     price_list = fields.Many2One('product.price_list', 'Price List',
             required=True, ondelete='CASCADE')
     product = fields.Many2One('product.product', 'Product')
-    sequence = fields.Integer('Sequence')
+    sequence = fields.Integer('Sequence', required=True)
     quantity = fields.Float('Quantity', digits=(16, Eval('unit_digits', 2)),
             depends=['unit_digits'])
     unit_digits = fields.Function(fields.Integer('Unit Digits',
